@@ -20,14 +20,40 @@
  */
 package org.apache.qpid.server.model;
 
+import java.util.UUID;
+
 import com.google.common.util.concurrent.ListenableFuture;
+import org.apache.qpid.server.message.MessageDestination;
 
 @ManagedObject(creatable = false, amqpName = "org.apache.qpid.Producer")
 public interface Producer<X extends Producer<X>> extends ConfiguredObject<X>
 {
     enum DeliveryType { DELAYED_DELIVERY, STANDARD_DELIVERY }
 
-    enum DestinationType { EXCHANGE, QUEUE }
+    enum DestinationType
+    {
+        EXCHANGE,
+        QUEUE;
+
+        public static DestinationType from(MessageDestination messageDestination)
+        {
+            if (messageDestination instanceof Exchange)
+            {
+                return EXCHANGE;
+            }
+            else if (messageDestination instanceof Queue)
+            {
+                return QUEUE;
+            }
+            return null;
+        }
+
+        public static UUID getId(MessageDestination messageDestination)
+        {
+            final DestinationType destinationType = from(messageDestination);
+            return destinationType == null ? null : ((ConfiguredObject<?>) messageDestination).getId();
+        }
+    }
 
     void registerMessageDelivered(long messageSize);
 
@@ -48,6 +74,11 @@ public interface Producer<X extends Producer<X>> extends ConfiguredObject<X>
 
     void setDestination(String destination);
 
+    @DerivedAttribute(description = "Destination id")
+    UUID getDestinationId();
+
+    void setDestinationId(UUID destinationId);
+
     @DerivedAttribute(description = "DeliveryType type (standard or delayed)")
     DeliveryType getDeliveryType();
 
