@@ -56,6 +56,8 @@ public class ProducerImpl<X extends Producer<X>>
 
     private String _destination;
 
+    private UUID _destinationId;
+
     public ProducerImpl(final AbstractAMQPSession<?, ?> session,
                         final PublishingLink publishingLink,
                         final MessageDestination messageDestination)
@@ -65,16 +67,16 @@ public class ProducerImpl<X extends Producer<X>>
         _sessionName = session.getName();
         _principal = session.getAMQPConnection().getPrincipal();
         _remoteAddress = session.getAMQPConnection().getRemoteAddress();
-        _destination = messageDestination == null ? null : messageDestination.getName();
         if (messageDestination == null)
         {
             _deliveryType = DeliveryType.DELAYED_DELIVERY;
-            _destinationType = null;
         }
         else
         {
             _deliveryType = DeliveryType.STANDARD_DELIVERY;
-            _destinationType = messageDestination instanceof Exchange ? DestinationType.EXCHANGE : DestinationType.QUEUE;
+            _destination = messageDestination.getName();
+            _destinationType = DestinationType.from(messageDestination);
+            _destinationId = DestinationType.getId(messageDestination);
         }
 
         registerWithParents();
@@ -149,6 +151,18 @@ public class ProducerImpl<X extends Producer<X>>
         _destination = destination;
     }
 
+    @Override
+    public UUID getDestinationId()
+    {
+        return _destinationId;
+    }
+
+    @Override
+    public void setDestinationId(UUID destinationId)
+    {
+        _destinationId = destinationId;
+    }
+
     @Override
     public DestinationType getDestinationType()
     {
