@@ -40,6 +40,7 @@ import org.apache.qpid.server.logging.Outcome;
 import org.apache.qpid.server.logging.messages.PortMessages;
 import org.apache.qpid.server.model.*;
 import org.apache.qpid.server.security.ManagedPeerCertificateTrustStore;
+import org.apache.qpid.server.security.SiteSpecificTrustStore;
 import org.apache.qpid.server.security.SubjectCreator;
 import org.apache.qpid.server.util.ParameterizedTypes;
 import org.apache.qpid.server.util.PortUtil;
@@ -84,11 +85,11 @@ public abstract class AbstractPort<X extends AbstractPort<X>> extends AbstractCo
     @ManagedAttributeField
     private String _bindingAddress;
 
-    private List<String> _tlsProtocolBlackList;
-    private List<String> _tlsProtocolWhiteList;
+    private List<String> _tlsProtocolDenyList;
+    private List<String> _tlsProtocolAllowList;
 
-    private List<String> _tlsCipherSuiteWhiteList;
-    private List<String> _tlsCipherSuiteBlackList;
+    private List<String> _tlsCipherSuiteAllowList;
+    private List<String> _tlsCipherSuiteDenyList;
 
     public AbstractPort(Map<String, Object> attributes,
                         Container<?> container)
@@ -109,10 +110,10 @@ public abstract class AbstractPort<X extends AbstractPort<X>> extends AbstractCo
     protected void onOpen()
     {
         super.onOpen();
-        _tlsProtocolWhiteList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST, CommonProperties.QPID_SECURITY_TLS_PROTOCOL_WHITE_LIST);
-        _tlsProtocolBlackList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST, CommonProperties.QPID_SECURITY_TLS_PROTOCOL_BLACK_LIST);
-        _tlsCipherSuiteWhiteList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST, CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_WHITE_LIST);
-        _tlsCipherSuiteBlackList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST, CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_BLACK_LIST);
+        _tlsProtocolAllowList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST);
+        _tlsProtocolDenyList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST);
+        _tlsCipherSuiteAllowList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST);
+        _tlsCipherSuiteDenyList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST);
     }
 
     @Override
@@ -184,6 +185,11 @@ public abstract class AbstractPort<X extends AbstractPort<X>> extends AbstractCo
                 throw new IllegalConfigurationException("Only trust stores of type " + ManagedPeerCertificateTrustStore.TYPE_NAME + " may be used as the client certificate recorder");
             }
         }
+        if (getTrustStores() != null && getTrustStores().stream().anyMatch(t -> t instanceof SiteSpecificTrustStore))
+        {
+            throw new IllegalConfigurationException(
+                    "Can't use trust store of type SiteSpecificTrustStore for the mutual authentication.");
+        }
     }
 
     private void validateAuthenticationMechanisms(final AuthenticationProvider<?> authenticationProvider,
@@ -273,25 +279,22 @@ public abstract class AbstractPort<X extends AbstractPort<X>> extends AbstractCo
         super.validateChange(proxyForValidation, changedAttributes);
         Port<?> updated = (Port<?>)proxyForValidation;
 
-
-        if(!getName().equals(updated.getName()))
+        if (!getName().equals(updated.getName()))
         {
             throw new IllegalConfigurationException("Changing the port name is not allowed");
         }
 
-        if(changedAttributes.contains(PORT))
+        if (changedAttributes.contains(PORT))
         {
             int newPort = updated.getPort();
             if (getPort() != newPort && newPort != 0)
             {
-                for (Port p : _container.getChildren(Port.class))
+                for (Port<?> p : _container.getChildren(Port.class))
                 {
                     if (p.getBoundPort() == newPort || p.getPort() == newPort)
                     {
-                        throw new IllegalConfigurationException("Port number "
-                                                                + newPort
-                                                                + " is already in use by port "
-                                                                + p.getName());
+                        throw new IllegalConfigurationException("Port number " + newPort +
+                                " is already in use by port " + p.getName());
                     }
                 }
             }
@@ -304,40 +307,42 @@ public abstract class AbstractPort<X extends AbstractPort<X>> extends AbstractCo
 
 
         boolean usesSsl = isUsingTLSTransport(transports);
-        if (usesSsl)
+        if (usesSsl && changedAttributes.contains(KEY_STORE) && updated.getKeyStore() == null)
         {
-            if (updated.getKeyStore() == null)
-            {
-                throw new IllegalConfigurationException("Can't create port which requires SSL but has no key store configured.");
-            }
+            throw new IllegalConfigurationException("Can't create port which requires SSL but has no key store configured.");
         }
 
-        if(changedAttributes.contains(Port.AUTHENTICATION_PROVIDER) || changedAttributes.contains(Port.TRANSPORTS))
+        if (changedAttributes.contains(Port.AUTHENTICATION_PROVIDER) || changedAttributes.contains(Port.TRANSPORTS))
         {
             validateAuthenticationMechanisms(updated.getAuthenticationProvider(), updated.getTransports());
         }
 
         boolean requiresCertificate = updated.getNeedClientAuth() || updated.getWantClientAuth();
 
-        if (usesSsl)
+        if (changedAttributes.contains(TRANSPORTS) || changedAttributes.contains(TRUST_STORES) ||
+                changedAttributes.contains(NEED_CLIENT_AUTH) || changedAttributes.contains(WANT_CLIENT_AUTH))
         {
-            if ((updated.getTrustStores() == null || updated.getTrustStores().isEmpty() ) && requiresCertificate)
+            if (usesSsl)
             {
-                throw new IllegalConfigurationException("Can't create port which requests SSL client certificates but has no trust store configured.");
+                if ((updated.getTrustStores() == null || updated.getTrustStores().isEmpty()) && requiresCertificate)
+                {
+                    throw new IllegalConfigurationException(
+                            "Can't create port which requests SSL client certificates but has no trust store configured.");
+                }
             }
-        }
-        else
-        {
-            if (requiresCertificate)
+            else
             {
-                throw new IllegalConfigurationException("Can't create port which requests SSL client certificates but doesn't use SSL transport.");
+                if (requiresCertificate)
+                {
+                    throw new IllegalConfigurationException(
+                            "Can't create port which requests SSL client certificates but doesn't use SSL transport.");
+                }
             }
         }
 
-
-        if(requiresCertificate && updated.getClientCertRecorder() != null)
+        if (requiresCertificate && updated.getClientCertRecorder() != null)
         {
-            if(!(updated.getClientCertRecorder() instanceof ManagedPeerCertificateTrustStore))
+            if (!(updated.getClientCertRecorder() instanceof ManagedPeerCertificateTrustStore))
             {
                 throw new IllegalConfigurationException("Only trust stores of type " + ManagedPeerCertificateTrustStore.TYPE_NAME + " may be used as the client certificate recorder");
             }
@@ -415,52 +420,28 @@ public abstract class AbstractPort<X extends AbstractPort<X>> extends AbstractCo
         return State.ACTIVE;
     }
 
-    @Override
-    public List<String> getTlsProtocolWhiteList()
-    {
-        return _tlsProtocolWhiteList;
-    }
-
-    @Override
-    public List<String> getTlsProtocolBlackList()
-    {
-        return _tlsProtocolBlackList;
-    }
-
-    @Override
-    public List<String> getTlsCipherSuiteWhiteList()
-    {
-        return _tlsCipherSuiteWhiteList;
-    }
-
-    @Override
-    public List<String> getTlsCipherSuiteBlackList()
-    {
-        return _tlsCipherSuiteBlackList;
-    }
-
     @Override
     public List<String> getTlsProtocolAllowList()
     {
-        return getTlsProtocolWhiteList();
+        return _tlsProtocolAllowList;
     }
 
     @Override
     public List<String> getTlsProtocolDenyList()
     {
-        return getTlsProtocolBlackList();
+        return _tlsProtocolDenyList;
     }
 
     @Override
     public List<String> getTlsCipherSuiteAllowList()
     {
-        return getTlsCipherSuiteWhiteList();
+        return _tlsCipherSuiteAllowList;
     }
 
     @Override
     public List<String> getTlsCipherSuiteDenyList()
     {
-        return getTlsCipherSuiteBlackList();
+        return _tlsCipherSuiteDenyList;
     }
 
     @Override
@@ -543,40 +524,19 @@ public abstract class AbstractPort<X extends AbstractPort<X>> extends AbstractCo
     protected void logCreated(final Map<String, Object> attributes,
                               final Outcome outcome)
     {
-        if (outcome == Outcome.SUCCESS)
-        {
-            _eventLogger.message(PortMessages.CREATE(getName()));
-        }
-        else
-        {
-            super.logCreated(attributes, outcome);
-        }
+        _eventLogger.message(PortMessages.CREATE(getName(), String.valueOf(outcome), attributesAsString(attributes)));
     }
 
     @Override
     protected void logRecovered(final Outcome outcome)
     {
-        if (outcome == Outcome.SUCCESS)
-        {
-            _eventLogger.message(PortMessages.CREATE(getName()));
-        }
-        else
-        {
-            super.logRecovered(outcome);
-        }
+        _eventLogger.message(PortMessages.OPEN(getName(), String.valueOf(outcome)));
     }
 
     @Override
     protected void logDeleted(final Outcome outcome)
     {
-        if (outcome == Outcome.SUCCESS)
-        {
-            _eventLogger.message(PortMessages.DELETE(getType(), getName()));
-        }
-        else
-        {
-            super.logDeleted(outcome);
-        }
+        _eventLogger.message(PortMessages.DELETE(getType(), getName()));
     }
 
     @Override
