@@ -28,6 +28,7 @@ import org.apache.qpid.server.model.DerivedAttribute;
 import org.apache.qpid.server.model.ManagedAttribute;
 import org.apache.qpid.server.model.ManagedContextDefault;
 import org.apache.qpid.server.model.ManagedObject;
+import org.apache.qpid.server.model.ManagedOperation;
 import org.apache.qpid.server.model.ManagedStatistic;
 import org.apache.qpid.server.model.Port;
 import org.apache.qpid.server.model.Protocol;
@@ -56,6 +57,10 @@ public interface AmqpPort<X extends AmqpPort<X>> extends Port<X>
     String PORT_AMQP_NUMBER_OF_SELECTORS = "qpid.port.amqp.threadPool.numberOfSelectors";
     String PORT_AMQP_ACCEPT_BACKLOG = "qpid.port.amqp.acceptBacklog";
 
+    String PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING = "qpid.port.amqp.diagnosisOfSslEngineLooping";
+    String PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING_WARN_THRESHOLD = "qpid.port.amqp.diagnosisOfSslEngineLoopingWarnThreshold";
+    String PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING_BREAK_THRESHOLD = "qpid.port.amqp.diagnosisOfSslEngineLoopingBreakThreshold";
+
     @ManagedContextDefault(name = DEFAULT_AMQP_PROTOCOLS)
     String INSTALLED_PROTOCOLS = AmqpPortImpl.getInstalledProtocolsAsString();
 
@@ -64,8 +69,26 @@ public interface AmqpPort<X extends AmqpPort<X>> extends Port<X>
     @ManagedContextDefault(name = PORT_MAX_OPEN_CONNECTIONS)
     int DEFAULT_MAX_OPEN_CONNECTIONS = -1;
 
+    @SuppressWarnings("unused")
+    @ManagedContextDefault( name = PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING)
+    boolean DEFAULT_PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING = false;
+
+    @SuppressWarnings("unused")
+    @ManagedContextDefault( name = PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING_WARN_THRESHOLD)
+    long DEFAULT_PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING_WARN_THRESHOLD = 1000;
+
+    @SuppressWarnings("unused")
+    @ManagedContextDefault( name = PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING_BREAK_THRESHOLD)
+    long DEFAULT_PORT_DIAGNOSIS_OF_SSL_ENGINE_LOOPING_BREAK_THRESHOLD = 1005;
+
     String PORT_IGNORE_INVALID_SNI = "qpid.port.amqp.ignoreInvalidSni";
 
+    /**
+     * In Java 17 logic SNI hostname validation became stricter and this flag will not help with the syntax errors
+     * in SNI hostnames provided by client. They will result in SSLPeerUnverifiedException thrown by SSLEngine.
+     * Therefore, usage of this flag is discouraged. It may be deleted in one of the future broker releases.
+     */
+    @Deprecated
     @SuppressWarnings("unused")
     @ManagedContextDefault(name = PORT_IGNORE_INVALID_SNI)
     boolean DEFAULT_PORT_IGNORE_INVALID_SNI = false;
@@ -172,14 +195,18 @@ public interface AmqpPort<X extends AmqpPort<X>> extends Port<X>
             label = "Open Connections",
             description = "Current number of connections made through this port",
             metricName = "open_connections_total")
-    int getConnectionCount();
+    long getConnectionCount();
 
     @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.COUNT,
             label = "Total Connections",
             description = "Total number of connections made through this port since broker startup",
-            metricName = "aggregate_connection_count")
+            metricName = "aggregate_connection_count",
+            resettable = true)
     long getTotalConnectionCount();
 
+    @ManagedOperation(description = "Resets port statistics", changesConfiguredObjectState = true)
+    void resetStatistics();
+
     @DerivedAttribute(description = "Maximum time allowed for a new connection to send a protocol header."
                                     + " If the connection does not send a protocol header within this time,"
                                     + " the connection will be aborted.")
@@ -204,11 +231,9 @@ public interface AmqpPort<X extends AmqpPort<X>> extends Port<X>
                                     + " 0 disables.")
     int getHeartbeatDelay();
 
-    boolean canAcceptNewConnection(final SocketAddress remoteSocketAddress);
+    boolean acceptNewConnectionAndIncrementCount(final SocketAddress remoteSocketAddress);
 
-    int incrementConnectionCount();
-
-    int decrementConnectionCount();
+    long decrementConnectionCount();
 
     int getNetworkBufferSize();
 
