@@ -89,7 +89,7 @@ public interface QueueManagingVirtualHost<X extends QueueManagingVirtualHost<X>>
 
 
     @ManagedContextDefault( name = "virtualhost.storeTransactionIdleTimeoutClose")
-    public static final long DEFAULT_STORE_TRANSACTION_IDLE_TIMEOUT_CLOSE = 0l;
+    public static final long DEFAULT_STORE_TRANSACTION_IDLE_TIMEOUT_CLOSE = 0L;
     @ManagedContextDefault( name = "virtualhost.housekeepingThreadCount")
     int DEFAULT_HOUSEKEEPING_THREAD_COUNT = 4;
 
@@ -104,11 +104,6 @@ public interface QueueManagingVirtualHost<X extends QueueManagingVirtualHost<X>>
                                          + " link detaches. This is to avoid leaking links with the Qpid JMS client.")
     boolean DEFAULT_DISCARD_GLOBAL_SHARED_SUBSCRIPTION_LINKS_ON_DETACH = true;
 
-    String CONNECTION_FREQUENCY_PERIOD = "qpid.virtualhost.connectionFrequencyPeriodInMillis";
-    @ManagedContextDefault(name = CONNECTION_FREQUENCY_PERIOD, description = "Interval (in milliseconds) to evaluate connection frequency")
-    @SuppressWarnings("unused")
-    long DEFAULT_CONNECTION_FREQUENCY_PERIOD = 60 * 1000;
-
     @ManagedAttribute( defaultValue = "${" + VIRTUALHOST_STATISTICS_REPORING_PERIOD + "}", description = "Period (in seconds) of the statistic report.")
     int getStatisticsReportingPeriod();
 
@@ -119,7 +114,7 @@ public interface QueueManagingVirtualHost<X extends QueueManagingVirtualHost<X>>
     long getStoreTransactionIdleTimeoutClose();
 
     @ManagedContextDefault( name = "virtualhost.storeTransactionIdleTimeoutWarn")
-    public static final long DEFAULT_STORE_TRANSACTION_IDLE_TIMEOUT_WARN = 180000l;
+    public static final long DEFAULT_STORE_TRANSACTION_IDLE_TIMEOUT_WARN = 180000L;
 
     @ManagedAttribute( defaultValue = "${virtualhost.storeTransactionIdleTimeoutWarn}",
             description = "The maximum length of time, in milliseconds, that an open store transaction may "
@@ -128,7 +123,7 @@ public interface QueueManagingVirtualHost<X extends QueueManagingVirtualHost<X>>
     long getStoreTransactionIdleTimeoutWarn();
 
     @ManagedContextDefault( name = "virtualhost.storeTransactionOpenTimeoutClose")
-    public static final long DEFAULT_STORE_TRANSACTION_OPEN_TIMEOUT_CLOSE = 0l;
+    public static final long DEFAULT_STORE_TRANSACTION_OPEN_TIMEOUT_CLOSE = 0L;
 
     @ManagedAttribute( defaultValue = "${virtualhost.storeTransactionOpenTimeoutClose}",
             description = "The maximum length of time, in milliseconds, that a store transaction may "
@@ -137,7 +132,7 @@ public interface QueueManagingVirtualHost<X extends QueueManagingVirtualHost<X>>
     long getStoreTransactionOpenTimeoutClose();
 
     @ManagedContextDefault( name = "virtualhost.storeTransactionOpenTimeoutWarn")
-    public static final long DEFAULT_STORE_TRANSACTION_OPEN_TIMEOUT_WARN = 300000l;
+    public static final long DEFAULT_STORE_TRANSACTION_OPEN_TIMEOUT_WARN = 300000L;
 
     @ManagedAttribute( defaultValue = "${virtualhost.storeTransactionOpenTimeoutWarn}",
             description = "The maximum length of time, in milliseconds, that a store transaction may "
@@ -229,40 +224,54 @@ public interface QueueManagingVirtualHost<X extends QueueManagingVirtualHost<X>>
     long getConnectionCount();
 
     @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.COUNT, label = "Total Connections",
-            description = "Total number of messaging connections made to this virtualhost since broker startup", metricName = "aggregate_connection_count")
+            description = "Total number of messaging connections made to this virtualhost since broker startup",
+            metricName = "aggregate_connection_count",
+            resettable = true)
     long getTotalConnectionCount();
 
 
     @SuppressWarnings("unused")
     @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.BYTES, label = "Inbound",
-                      description = "Total size of all messages received by this virtualhost.", metricName = "inbound_bytes_count")
+            description = "Total size of all messages received by this virtualhost.",
+            metricName = "inbound_bytes_count",
+            resettable = true)
     long getBytesIn();
 
     @SuppressWarnings("unused")
     @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.BYTES, label = "Outbound",
-                      description = "Total size of all messages delivered by this virtualhost.", metricName = "outbound_bytes_count")
+            description = "Total size of all messages delivered by this virtualhost.",
+            metricName = "outbound_bytes_count",
+            resettable = true)
     long getBytesOut();
 
     @SuppressWarnings("unused")
     @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.MESSAGES, label = "Inbound",
-                      description = "Total number of messages received by this virtualhost.", metricName = "inbound_messages_count")
+            description = "Total number of messages received by this virtualhost.",
+            metricName = "inbound_messages_count",
+            resettable = true)
     long getMessagesIn();
 
     @SuppressWarnings("unused")
     @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.MESSAGES, label = "Outbound",
-                      description = "Total number of messages delivered by this virtualhost.", metricName = "outbound_messages_count")
+            description = "Total number of messages delivered by this virtualhost.",
+            metricName = "outbound_messages_count",
+            resettable = true)
     long getMessagesOut();
 
     @SuppressWarnings("unused")
     @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.MESSAGES,
             label = "Transacted Inbound",
-            description = "Total number of messages delivered by this virtualhost within a transaction.", metricName = "inbound_transacted_messages_count")
+            description = "Total number of messages delivered by this virtualhost within a transaction.",
+            metricName = "inbound_transacted_messages_count",
+            resettable = true)
     long getTransactedMessagesIn();
 
     @SuppressWarnings("unused")
     @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.MESSAGES,
             label = "Transacted Outbound",
-            description = "Total number of messages received by this virtualhost within a transaction.", metricName = "outbound_transacted_messages_count")
+            description = "Total number of messages received by this virtualhost within a transaction.",
+            metricName = "outbound_transacted_messages_count",
+            resettable = true)
     long getTransactedMessagesOut();
 
     @SuppressWarnings("unused")
@@ -289,16 +298,22 @@ public interface QueueManagingVirtualHost<X extends QueueManagingVirtualHost<X>>
 
     @SuppressWarnings("unused")
     @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.BYTES, label = "Evacuated Message Bytes",
-                      description = "Total Number of Bytes Evacuated from Memory Due to Flow to Disk.")
+            description = "Total Number of Bytes Evacuated from Memory Due to Flow to Disk.",
+            resettable = true)
     long getBytesEvacuatedFromMemory();
 
     @SuppressWarnings("unused")
     @ManagedStatistic(statisticType = StatisticType.POINT_IN_TIME,
             units = StatisticUnit.BYTES,
             label = "Maximum recorded size of inbound messages",
-            description = "Maximum size of message published into the Virtual Host since start-up.", metricName = "inbound_message_size_high_water_mark")
+            description = "Maximum size of message published into the Virtual Host since start-up.",
+            metricName = "inbound_message_size_high_water_mark",
+            resettable = true)
     long getInboundMessageSizeHighWatermark();
 
+    @ManagedOperation(description = "Resets Virtual Host statistics", changesConfiguredObjectState = true)
+    void resetStatistics();
+
     @Override
     @ManagedOperation(nonModifying = true, changesConfiguredObjectState = false)
     Collection<? extends Connection<?>> getConnections();
@@ -348,6 +363,12 @@ public interface QueueManagingVirtualHost<X extends QueueManagingVirtualHost<X>>
                            @Param(name = "role", description = "whether to remove only sending links (\"SENDER\"), receiving links (\"RECEIVER\") or both (\"BOTH\")", validValues = {"SENDER", "RECEIVER", "BOTH"}, defaultValue = "BOTH") String role,
                            @Param(name = "linkNamePattern", description = "Regular Expression to match the link names to be removed.", defaultValue = ".*") String linkNamePattern);
 
+    @ManagedOperation(description = "Purge every queue with the name that matches the regular expression.", changesConfiguredObjectState = false)
+    long clearMatchingQueues(@Param(name = "queueNamePattern", description = "Regular Expression to match the queue name.", defaultValue = ".*") String queueNamePattern);
+
+    @ManagedOperation(description = "Purge queues in provided list.", changesConfiguredObjectState = false)
+    long clearQueues(@Param(name = "queues", description = "Collection of queue IDs or names.") Collection<String> queues);
+
     Queue<?> getSubscriptionQueue(final String exchangeName,
                                   final Map<String, Object> attributes,
                                   final Map<String, Map<String, Object>> bindings);
