@@ -20,8 +20,8 @@
  */
 package org.apache.qpid.server.transport;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.ArgumentMatchers.anyLong;
 import static org.mockito.Mockito.inOrder;
 import static org.mockito.Mockito.mock;
@@ -31,83 +31,80 @@ import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
 import com.google.common.base.Supplier;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+
 import org.mockito.InOrder;
 
 import org.apache.qpid.server.util.Action;
 import org.apache.qpid.test.utils.UnitTestBase;
 
+@SuppressWarnings("unchecked")
 public class TransactionTimeoutTickerTest extends UnitTestBase
 {
+    private TransactionTimeoutTicker _ticker;
     private final Supplier<Long> _dateSupplier = mock(Supplier.class);
-    private final Action<Long> _notificationAction = mock(Action.class);
+    private Action<Long> _notificationAction;
     private final long _timeoutValue = 100;
     private final long _notificationRepeatPeriod = 5000;
 
-    private TransactionTimeoutTicker _ticker;
+    @BeforeEach
+    public void setUp()
+    {
+        _notificationAction = mock(Action.class);
+    }
 
     @Test
-    public void testTickWhenNoTransaction() throws Exception
+    public void testTickWhenNoTransaction()
     {
         final long timeNow = System.currentTimeMillis();
 
         when(_dateSupplier.get()).thenReturn(0L);
 
-        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod,
-                                               _dateSupplier,
-                                               _notificationAction);
+        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod, _dateSupplier, _notificationAction);
 
-        assertTickTime("Unexpected ticker value when no transaction is in-progress",
-                       Integer.MAX_VALUE,
-                       timeNow, _ticker);
+        assertTickTime("Unexpected ticker value when no transaction is in-progress", Integer.MAX_VALUE,
+                timeNow, _ticker);
 
         verify(_notificationAction, never()).performAction(anyLong());
     }
 
     @Test
-    public void testTickDuringSingleTransaction() throws Exception
+    public void testTickDuringSingleTransaction()
     {
         final long timeNow = System.currentTimeMillis();
         final long transactionTime = timeNow - 90;
 
         when(_dateSupplier.get()).thenReturn(transactionTime);
 
-        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod,
-                                               _dateSupplier,
-                                               _notificationAction);
+        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod, _dateSupplier, _notificationAction);
 
         final int expected = 10;
-        assertTickTime("Unexpected ticker value when transaction is in-progress",
-                       expected,
-                       timeNow, _ticker);
+        assertTickTime("Unexpected ticker value when transaction is in-progress", expected, timeNow, _ticker);
 
         verify(_notificationAction, never()).performAction(anyLong());
     }
 
     @Test
-    public void testTickDuringSingleTransactionWithSchedulingDelay() throws Exception
+    public void testTickDuringSingleTransactionWithSchedulingDelay()
     {
         final long timeNow = System.currentTimeMillis();
         final long transactionTime = timeNow - 90;
 
         when(_dateSupplier.get()).thenReturn(transactionTime);
 
-        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod,
-                                               _dateSupplier,
-                                               _notificationAction);
+        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod, _dateSupplier, _notificationAction);
 
         _ticker.notifySchedulingDelay(10);
 
         final int expected = 20;
-        assertTickTime("Unexpected ticker value when transaction is in-progress",
-                       expected,
-                       timeNow, _ticker);
+        assertTickTime("Unexpected ticker value when transaction is in-progress", expected, timeNow, _ticker);
 
         verify(_notificationAction, never()).performAction(anyLong());
     }
 
     @Test
-    public void testTicksDuringManyTransactions() throws Exception
+    public void testTicksDuringManyTransactions()
     {
         long timeNow = System.currentTimeMillis();
         final long firstTransactionTime = timeNow - 10;
@@ -115,14 +112,11 @@ public class TransactionTimeoutTickerTest extends UnitTestBase
         // First transaction
         when(_dateSupplier.get()).thenReturn(firstTransactionTime);
 
-        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod,
-                                               _dateSupplier,
-                                               _notificationAction);
+        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod, _dateSupplier, _notificationAction);
 
         final int expectedTickForFirstTransaction = 90;
-        assertTickTime("Unexpected ticker value for first transaction",
-                       expectedTickForFirstTransaction,
-                       timeNow, _ticker);
+        assertTickTime("Unexpected ticker value for first transaction", expectedTickForFirstTransaction,
+                timeNow, _ticker);
 
         // Second transaction
         timeNow += 100;
@@ -131,15 +125,14 @@ public class TransactionTimeoutTickerTest extends UnitTestBase
         when(_dateSupplier.get()).thenReturn(secondTransactionTime);
 
         final int expectedTickForSecondTransaction = 95;
-        assertTickTime("Unexpected ticker value for second transaction",
-                       expectedTickForSecondTransaction,
-                       timeNow, _ticker);
+        assertTickTime("Unexpected ticker value for second transaction", expectedTickForSecondTransaction,
+                timeNow, _ticker);
 
         verify(_notificationAction, never()).performAction(anyLong());
     }
 
     @Test
-    public void testTicksDuringManyTransactionsWithSchedulingDelay() throws Exception
+    public void testTicksDuringManyTransactionsWithSchedulingDelay()
     {
         long timeNow = System.currentTimeMillis();
         final long firstTransactionTime = timeNow - 10;
@@ -147,15 +140,12 @@ public class TransactionTimeoutTickerTest extends UnitTestBase
         // First transaction
         when(_dateSupplier.get()).thenReturn(firstTransactionTime);
 
-        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod,
-                                               _dateSupplier,
-                                               _notificationAction);
+        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod, _dateSupplier, _notificationAction);
 
         _ticker.notifySchedulingDelay(5);
         final int expectedTickForFirstTransaction = 95;
-        assertTickTime("Unexpected ticker value for first transaction",
-                       expectedTickForFirstTransaction,
-                       timeNow, _ticker);
+        assertTickTime("Unexpected ticker value for first transaction", expectedTickForFirstTransaction,
+                timeNow, _ticker);
 
         // Second transaction. scheduling delay should have been cleared
         timeNow += 100;
@@ -164,51 +154,44 @@ public class TransactionTimeoutTickerTest extends UnitTestBase
         when(_dateSupplier.get()).thenReturn(secondTransactionTime);
 
         final int expectedTickForSecondTransaction = 95;
-        assertTickTime("Unexpected ticker value for second transaction",
-                       expectedTickForSecondTransaction,
-                       timeNow, _ticker);
+        assertTickTime("Unexpected ticker value for second transaction", expectedTickForSecondTransaction,
+                timeNow, _ticker);
 
         verify(_notificationAction, never()).performAction(anyLong());
     }
 
     @Test
-    public void testSingleTimeoutsDuringSingleTransaction() throws Exception
+    public void testSingleTimeoutsDuringSingleTransaction()
     {
         long timeNow = System.currentTimeMillis();
         final long transactionTime = timeNow - 110;
 
         when(_dateSupplier.get()).thenReturn(transactionTime);
 
-        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod,
-                                               _dateSupplier,
-                                               _notificationAction);
+        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod, _dateSupplier, _notificationAction);
 
 
         final long expectedInitialIdle = 110L;
-        assertTickerTimeout("Unexpected ticker value when transaction is in-progress",
-                            timeNow, _ticker);
+        assertTickerTimeout("Unexpected ticker value when transaction is in-progress", timeNow, _ticker);
 
         verify(_notificationAction, times(1)).performAction(expectedInitialIdle);
     }
 
     @Test
-    public void testMultipleTimeoutsDuringSingleTransaction_NotificationsRespectPeriod() throws Exception
+    public void testMultipleTimeoutsDuringSingleTransaction_NotificationsRespectPeriod()
     {
-        InOrder inorder = inOrder(_notificationAction);
+        final InOrder inorder = inOrder(_notificationAction);
 
         long timeNow = System.currentTimeMillis();
         final long transactionTime = timeNow - 110;
 
         when(_dateSupplier.get()).thenReturn(transactionTime);
 
-        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod,
-                                               _dateSupplier,
-                                               _notificationAction);
+        _ticker = new TransactionTimeoutTicker(_timeoutValue, _notificationRepeatPeriod, _dateSupplier, _notificationAction);
 
 
         final long expectedInitialIdle = 110L;
-        assertTickerTimeout("Unexpected ticker value when transaction is in-progress",
-                            timeNow, _ticker);
+        assertTickerTimeout("Unexpected ticker value when transaction is in-progress", timeNow, _ticker);
 
         inorder.verify(_notificationAction, times(1)).performAction(expectedInitialIdle);
 
@@ -216,11 +199,8 @@ public class TransactionTimeoutTickerTest extends UnitTestBase
         final long timeAdjustment = _notificationRepeatPeriod / 2;
         timeNow += timeAdjustment;
 
-        final long expectedNotificationTick = timeAdjustment;
-        assertTickTime("Unexpected ticker value when transaction is in-progress after notification",
-                       expectedNotificationTick,
-                       timeNow,
-                       _ticker);
+        assertTickTime("Unexpected ticker value when transaction is in-progress after notification", timeAdjustment,
+                timeNow, _ticker);
 
         inorder.verify(_notificationAction, never()).performAction(anyLong());
 
@@ -230,7 +210,7 @@ public class TransactionTimeoutTickerTest extends UnitTestBase
         timeNow += timeAdjustment;
         final long expectedSecondIdle = timeNow - transactionTime;
         assertTickerTimeout("Unexpected ticker value when transaction is in-progress and renotification is due",
-                            timeNow, _ticker);
+                timeNow, _ticker);
 
         inorder.verify(_notificationAction, times(1)).performAction(expectedSecondIdle);
 
@@ -240,8 +220,8 @@ public class TransactionTimeoutTickerTest extends UnitTestBase
                                      final long currentTime,
                                      final TransactionTimeoutTicker ticker)
     {
-        assertTrue(message, ticker.getTimeToNextTick(currentTime) <= 0);
-        assertTrue(message, ticker.tick(currentTime) <= 0);
+        assertTrue(ticker.getTimeToNextTick(currentTime) <= 0, message);
+        assertTrue(ticker.tick(currentTime) <= 0, message);
     }
 
     private void assertTickTime(final String message,
@@ -249,7 +229,7 @@ public class TransactionTimeoutTickerTest extends UnitTestBase
                                 final long currentTime,
                                 final TransactionTimeoutTicker ticker)
     {
-        assertEquals(message, expectedValue, (long) ticker.getTimeToNextTick(currentTime));
-        assertEquals(message, expectedValue, (long) ticker.tick(currentTime));
+        assertEquals(expectedValue, ticker.getTimeToNextTick(currentTime), message);
+        assertEquals(expectedValue, ticker.tick(currentTime), message);
     }
 }
