@@ -185,7 +185,7 @@ public class AMQPConnection_1_0Impl extends AbstractAMQPConnection<AMQPConnectio
     private final SubjectCreator _subjectCreator;
 
     private int _channelMax = 0;
-    private int _maxFrameSize = 4096;
+    private int _maxFrameSize;
     private String _remoteContainerId;
 
     private SocketAddress _remoteAddress;
@@ -262,6 +262,8 @@ public class AMQPConnection_1_0Impl extends AbstractAMQPConnection<AMQPConnectio
         _incomingIdleTimeout = 1000L * port.getHeartbeatDelay();
 
         _frameWriter = new FrameWriter(getDescribedTypeRegistry(), getSender());
+
+        _maxFrameSize = getBroker().getNetworkBufferSize();
     }
 
     @Override
@@ -895,7 +897,7 @@ public class AMQPConnection_1_0Impl extends AbstractAMQPConnection<AMQPConnectio
         }
         else
         {
-            initialiseHeartbeating(_outgoingIdleTimeout / 2L, _incomingIdleTimeout);
+            initialiseHeartbeating(_outgoingIdleTimeout / 2L, _incomingIdleTimeout * 2);
             final NamedAddressSpace addressSpace = getPort().getAddressSpace(_localHostname);
             if (addressSpace == null)
             {
