@@ -45,8 +45,6 @@ import org.apache.qpid.server.message.MessageDestination;
 import org.apache.qpid.server.message.MessageReference;
 import org.apache.qpid.server.message.MessageSender;
 import org.apache.qpid.server.message.ServerMessage;
-import org.apache.qpid.server.model.DestinationAddress;
-import org.apache.qpid.server.model.Exchange;
 import org.apache.qpid.server.model.Producer;
 import org.apache.qpid.server.model.PublishingLink;
 import org.apache.qpid.server.plugin.MessageFormat;
@@ -296,14 +294,8 @@ public class StandardReceivingLinkEndpoint extends AbstractReceivingLinkEndpoint
                                     {
                                         final MessageDestination messageDestination = getAddressSpace()
                                                 .getAttainedMessageDestination(serverMessage.getTo(), false);
-                                        if (messageDestination != null)
-                                        {
-                                            final Producer.DestinationType destinationType =
-                                                    messageDestination instanceof Exchange
-                                                            ? Producer.DestinationType.EXCHANGE
-                                                            : Producer.DestinationType.QUEUE;
-                                            _producer.setDestinationType(destinationType);
-                                        }
+                                        _producer.setDestinationType(Producer.DestinationType.from(messageDestination));
+                                        _producer.setDestinationId(Producer.DestinationType.getId(messageDestination));
                                         _producer.setDestination(to);
                                     }
                                 }
