@@ -25,11 +25,9 @@ import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.notNullValue;
 import static org.hamcrest.CoreMatchers.startsWith;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assume.assumeFalse;
-import static org.junit.Assume.assumeTrue;
+import static org.junit.jupiter.api.Assumptions.assumeFalse;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
-import java.util.Arrays;
-import java.util.Collections;
 import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.List;
@@ -40,10 +38,10 @@ import java.util.concurrent.TimeUnit;
 import com.google.common.collect.Lists;
 import com.google.common.util.concurrent.Futures;
 import com.google.common.util.concurrent.ListenableFuture;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TestName;
+
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestInfo;
 
 import org.apache.qpid.server.model.Protocol;
 import org.apache.qpid.systests.end_to_end_conversion.client.ClientInstruction;
@@ -53,6 +51,12 @@ import org.apache.qpid.systests.end_to_end_conversion.client.MessageDescription;
 import org.apache.qpid.systests.end_to_end_conversion.client.SerializableTestClass;
 import org.apache.qpid.systests.end_to_end_conversion.client.VerificationException;
 
+/**
+ * When running behind the proxy, test may hang due to maven resolver plugin failing to establish connection with the
+ * central repository. To run the test behind the proxy either declare an environment variable named "https_proxy" in
+ * form "export https_proxy=hostname:port" or supply a system property with the same name in form
+ * -Dhttps_proxy=hostname:port
+ */
 public class SimpleConversionTest extends EndToEndConversionTestBase
 {
     private static final long TEST_TIMEOUT = 30000L;
@@ -62,13 +66,22 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     private static final String JMS_MESSAGE_IDPOLICY_MESSAGE_IDTYPE = "jms.messageIDPolicy.messageIDType";
 
     private HashMap<String, String> _defaultDestinations;
-    @Rule
-    public TestName _testName = new TestName();
 
-    @Before
+    /**
+     * JUnit TestInfo
+     */
+    private TestInfo _testInfo;
+
+    @BeforeEach
+    public void init(final TestInfo testInfo)
+    {
+        _testInfo = testInfo;
+    }
+
+    @BeforeEach
     public void setup()
     {
-        final String queueName = _testName.getMethodName();
+        final String queueName = _testInfo.getTestMethod().orElseThrow(() -> new RuntimeException("Failed to resolve test method")).getName();
         getBrokerAdmin().createQueue(queueName);
 
         _defaultDestinations = new HashMap<>();
@@ -148,8 +161,7 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     {
         final MessageDescription messageDescription = new MessageDescription();
         messageDescription.setMessageType(MessageDescription.MessageType.OBJECT_MESSAGE);
-        messageDescription.setContent(new SerializableTestClass(Collections.singletonMap("testKey", "testValue"),
-                                                                Collections.singletonList(42)));
+        messageDescription.setContent(new SerializableTestClass(Map.of("testKey", "testValue"), List.of(42)));
 
         performSimpleTest(messageDescription);
     }
@@ -187,10 +199,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId09_010() throws Exception
     {
-        assumeTrue(AMQP_PRE010_PROTOCOLS.contains(getPublisherProtocolVersion())
-                   && EnumSet.of(Protocol.AMQP_0_10).contains(getSubscriberProtocolVersion()));
+        assumeTrue(AMQP_PRE010_PROTOCOLS.contains(getPublisherProtocolVersion()) &&
+                EnumSet.of(Protocol.AMQP_0_10).contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.emptyMap());
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of());
 
         ClientMessage publishedMessage = clientResults.get(0);
         ClientMessage subscriberMessage = clientResults.get(1);
@@ -202,10 +214,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId09_10() throws Exception
     {
-        assumeTrue(AMQP_PRE010_PROTOCOLS.contains(getPublisherProtocolVersion())
-                   && EnumSet.of(Protocol.AMQP_1_0).contains(getSubscriberProtocolVersion()));
+        assumeTrue(AMQP_PRE010_PROTOCOLS.contains(getPublisherProtocolVersion()) &&
+                EnumSet.of(Protocol.AMQP_1_0).contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.emptyMap());
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of());
 
         ClientMessage publishedMessage = clientResults.get(0);
         ClientMessage subscriberMessage = clientResults.get(1);
@@ -220,10 +232,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId010_09() throws Exception
     {
-        assumeTrue(EnumSet.of(Protocol.AMQP_0_10).contains(getPublisherProtocolVersion())
-                   && AMQP_PRE010_PROTOCOLS.contains(getSubscriberProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_0_10).contains(getPublisherProtocolVersion()) &&
+                AMQP_PRE010_PROTOCOLS.contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.emptyMap());
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of());
 
         ClientMessage publishedMessage = clientResults.get(0);
         ClientMessage subscriberMessage = clientResults.get(1);
@@ -236,10 +248,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId010_10() throws Exception
     {
-        assumeTrue(EnumSet.of(Protocol.AMQP_0_10).contains(getPublisherProtocolVersion())
-                   && EnumSet.of(Protocol.AMQP_1_0).contains(getSubscriberProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_0_10).contains(getPublisherProtocolVersion()) &&
+                EnumSet.of(Protocol.AMQP_1_0).contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.emptyMap());
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of());
 
         ClientMessage publishedMessage = clientResults.get(0);
         ClientMessage subscriberMessage = clientResults.get(1);
@@ -256,10 +268,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId_DefaultMode_10_09() throws Exception
     {
-        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion())
-                   && AMQP_PRE010_PROTOCOLS.contains(getSubscriberProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()) &&
+                AMQP_PRE010_PROTOCOLS.contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.emptyMap());
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of());
 
         // On the wire the "message-id-string comprises an identity of the publisher + a message sequence number
         ClientMessage publishedMessage = clientResults.get(0);
@@ -271,11 +283,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId_UuidMode_10_09() throws Exception
     {
-        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion())
-                   && AMQP_PRE010_PROTOCOLS
-                           .contains(getSubscriberProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()) &&
+                AMQP_PRE010_PROTOCOLS.contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.singletonMap(
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of(
                 JMS_MESSAGE_IDPOLICY_MESSAGE_IDTYPE, "UUID"));
 
         ClientMessage publishedMessage = clientResults.get(0);
@@ -292,10 +303,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId_UuidStringMode_10_09() throws Exception
     {
-        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion())
-                   && AMQP_PRE010_PROTOCOLS.contains(getSubscriberProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()) &&
+                AMQP_PRE010_PROTOCOLS.contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.singletonMap(
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of(
                 JMS_MESSAGE_IDPOLICY_MESSAGE_IDTYPE, "UUID_STRING"));
 
         ClientMessage publishedMessage = clientResults.get(0);
@@ -313,10 +324,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId_PrefixedUuidStringMode_10_09() throws Exception
     {
-        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion())
-                   && AMQP_PRE010_PROTOCOLS.contains(getSubscriberProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()) &&
+                AMQP_PRE010_PROTOCOLS.contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.singletonMap(
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of(
                 JMS_MESSAGE_IDPOLICY_MESSAGE_IDTYPE, "PREFIXED_UUID_STRING"));
 
         ClientMessage publishedMessage = clientResults.get(0);
@@ -333,10 +344,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId_DefaultMode_10_010() throws Exception
     {
-        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion())
-                   && EnumSet.of(Protocol.AMQP_0_10).contains(getSubscriberProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()) &&
+                EnumSet.of(Protocol.AMQP_0_10).contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.emptyMap());
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of());
 
         // On the wire the message-id is a message-id-string comprising an identity of the pubisher + a message
         // sequence number
@@ -350,10 +361,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId_UuidMode_10_010() throws Exception
     {
-        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion())
-                   && EnumSet.of(Protocol.AMQP_0_10).contains(getSubscriberProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()) &&
+                EnumSet.of(Protocol.AMQP_0_10).contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.singletonMap(
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of(
                 JMS_MESSAGE_IDPOLICY_MESSAGE_IDTYPE, "UUID"));
 
         ClientMessage publishedMessage = clientResults.get(0);
@@ -370,10 +381,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId_UuidStringMode_10_010() throws Exception
     {
-        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion())
-                   && EnumSet.of(Protocol.AMQP_0_10).contains(getSubscriberProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()) &&
+                EnumSet.of(Protocol.AMQP_0_10).contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.singletonMap(
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of(
                 JMS_MESSAGE_IDPOLICY_MESSAGE_IDTYPE, "UUID_STRING"));
 
         ClientMessage publishedMessage = clientResults.get(0);
@@ -390,10 +401,10 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void providerAssignedMessageId_PrefixedUuidStringMode_10_010() throws Exception
     {
-        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion())
-                   && EnumSet.of(Protocol.AMQP_0_10).contains(getSubscriberProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()) &&
+                EnumSet.of(Protocol.AMQP_0_10).contains(getSubscriberProtocolVersion()));
 
-        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Collections.singletonMap(
+        List<ClientMessage> clientResults = performProviderAssignedMessageIdTest(Map.of(
                 JMS_MESSAGE_IDPOLICY_MESSAGE_IDTYPE, "PREFIXED_UUID_STRING"));
 
         ClientMessage publishedMessage = clientResults.get(0);
@@ -426,7 +437,7 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void replyToStaticQueue() throws Exception
     {
-        final String replyQueueName = _testName.getMethodName() + "ReplyQueue";
+        final String replyQueueName = _testInfo.getTestMethod().orElseThrow(() -> new RuntimeException("Failed to resolve test method")).getName() + "ReplyQueue";
         final String replyQueueJndiName = "replyQueue";
         _defaultDestinations.put("queue." + replyQueueJndiName, replyQueueName);
         getBrokerAdmin().createQueue(replyQueueName);
@@ -442,8 +453,8 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void replyToAmqp10Topic() throws Exception
     {
-        assumeTrue("This test is for AMQP 1.0 publisher",
-                    EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()),
+                "This test is for AMQP 1.0 publisher");
 
         final String replyTopicJndiName = "replyTopic";
         _defaultDestinations.put("topic." + replyTopicJndiName, "amq.topic/topic");
@@ -453,8 +464,8 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void replyToAmqp0xTopic() throws Exception
     {
-        assumeFalse("This test is for AMQP 0-x publisher",
-                    EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()));
+        assumeFalse(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()),
+                "This test is for AMQP 0-x publisher");
 
         String jndiName = "testTopic";
         _defaultDestinations.put("topic." + jndiName, "myTopic");
@@ -464,11 +475,11 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void replyToBURLDestination() throws Exception
     {
-        assumeFalse("This test is for AMQP 0-x publisher",
-                   EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()));
+        assumeFalse(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()),
+                "This test is for AMQP 0-x publisher");
 
         String jndiName = "testDestination";
-        String testDestination = _testName.getMethodName() + "MyQueue";
+        String testDestination = _testInfo.getTestMethod().orElseThrow(() -> new RuntimeException("Failed to resolve test method")).getName() + "MyQueue";
         _defaultDestinations.put("destination." + jndiName,
                                  String.format("BURL:direct://amq.direct//%s?routingkey='%s'", testDestination, testDestination));
 
@@ -480,15 +491,15 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
     @Test
     public void replyToAddressDestination() throws Exception
     {
-        assumeFalse("This test is for AMQP 0-x publisher",
-                    EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()));
+        assumeFalse(EnumSet.of(Protocol.AMQP_1_0).contains(getPublisherProtocolVersion()),
+                "This test is for AMQP 0-x publisher");
 
-        assumeTrue("QPID-7902: setJMSReplyTo for address based destination is broken on client side for 0-8...0-9-1",
-                    EnumSet.of(Protocol.AMQP_0_10).contains(getPublisherProtocolVersion()));
+        assumeTrue(EnumSet.of(Protocol.AMQP_0_10).contains(getPublisherProtocolVersion()),
+                "QPID-7902: setJMSReplyTo for address based destination is broken on client side for 0-8...0-9-1");
 
         String replyToJndiName = "replyToJndiName";
         String consumeReplyToJndiName = "consumeReplyToJndiName";
-        String testDestination = _testName.getMethodName() + "MyQueue";
+        String testDestination = _testInfo.getTestMethod().orElseThrow(() -> new RuntimeException("Failed to resolve test method")).getName() + "MyQueue";
         _defaultDestinations.put("destination." + replyToJndiName, "ADDR: amq.fanout/testReplyToQueue");
         _defaultDestinations.put("destination." + consumeReplyToJndiName,
                                  "ADDR: testReplyToQueue; {create:always, node: {type: queue, x-bindings:[{exchange: 'amq.fanout', key: testReplyToQueue}]}}");
@@ -579,17 +590,17 @@ public class SimpleConversionTest extends EndToEndConversionTestBase
                 new ClientInstructionBuilder().configureDestinations(_defaultDestinations)
                                               .receiveMessage(destinationJndiName, messageDescription)
                                               .build();
-        List<ClientResult> clientResults = performTest(publisherInstructions, subscriberInstructions);
+        final List<ClientResult> clientResults = performTest(publisherInstructions, subscriberInstructions);
         assertThat("Unexpected number of client results", clientResults.size(), equalTo(2));
 
-        ClientResult publishedClientResult = clientResults.get(0);
+        final ClientResult publishedClientResult = clientResults.get(0);
         assertThat("Unexpected number of published client messages", publishedClientResult.getClientMessages().size(), equalTo(1));
-        ClientMessage publishedMessage = publishedClientResult.getClientMessages().get(0);
+        final ClientMessage publishedMessage = publishedClientResult.getClientMessages().get(0);
 
-        ClientResult subscriberClientResults = clientResults.get(1);
+        final ClientResult subscriberClientResults = clientResults.get(1);
         assertThat("Unexpected number of published client messages", subscriberClientResults.getClientMessages().size(), equalTo(1));
-        ClientMessage subscriberMessage = subscriberClientResults.getClientMessages().get(0);
+        final ClientMessage subscriberMessage = subscriberClientResults.getClientMessages().get(0);
 
-        return Arrays.asList(publishedMessage, subscriberMessage);
+        return List.of(publishedMessage, subscriberMessage);
     }
 }
